@@ -6,13 +6,13 @@ import time
 from getmac import get_mac_address as gma
 
 
-def inference(img_path, lang):
+def inference(img_path,lang,model_rec,model_det):
     try:
         macadd=gma()
         uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
-            ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=False,rec_model_dir='paddleocr/rec/',det_model_dir='paddleocr/det/')
+            ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=False,rec_model_dir=model_rec,det_model_dir=model_det)
             result = ocr.ocr(img_path, cls=True)
             txts = [line[1][0] for line in result]
             scores = [line[1][1] for line in result]
